Cli class
The main CLI entry point for Archit.
This class handles the command-line interface flow, including detecting Flutter projects and routing to the appropriate commands.
Constructors
- Cli()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
List< String> args) → Future<void> - Runs the CLI with the given arguments.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited