FeatureManagerCommand class

Command for managing features in a Flutter project.

Provides an interactive interface to add features and manage their usecases within a clean architecture structure.

Constructors

FeatureManagerCommand({required String projectPath, required StateManagement stateManagement})
Creates a new FeatureManagerCommand.

Properties

featuresPath String
Returns the path to the features directory.
no setter
hashCode int
The hash code for this object.
no setterinherited
projectPath String
The path to the Flutter project.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateManagement StateManagement
The state management solution used in the project.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() Future<void>
Runs the feature manager interactive loop.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited