CoreGenerator class
Generates the core architecture layer of a Flutter project.
Creates the standard clean architecture structure including constants, errors, network layer, usecases, theme, utils, routes, and DI.
Constructors
- CoreGenerator(String projectPath, ProjectConfig config)
- Creates a new CoreGenerator.
Properties
- config → ProjectConfig
-
The project configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- libPath → String
-
Returns the path to the lib directory.
no setter
- projectPath → String
-
The path to the Flutter project.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
) → void - Generates all core architecture files.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited