UsecaseGenerator class

Generates a new usecase for an existing feature.

Creates the usecase file and updates the data source, repository interface and implementation, and dependency injection.

Constructors

UsecaseGenerator(String projectPath, StateManagement stateManagement)
Creates a new UsecaseGenerator.

Properties

hashCode int
The hash code for this object.
no setterinherited
libPath String
Returns the path to the lib directory.
no setter
projectPath String
The path to the Flutter project.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateManagement StateManagement
The state management solution used in the project.
final

Methods

generateUsecase(String featureName, String usecaseName) → void
Generates a usecase and wires it through the architecture.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited