ProjectConfig class

Configuration for a Flutter project.

Contains all the settings needed to scaffold a Flutter project with clean architecture.

Constructors

ProjectConfig({required String name, required ProjectType type, required List<Platform> platforms, required StateManagement stateManagement})
Creates a new ProjectConfig.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The project name in snake_case.
final
platforms List<Platform>
The target platforms for this project.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateManagement StateManagement
The state management solution to use.
final
type ProjectType
The type of project (app or package).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited