StateManagement enum

Available state management solutions.

Inheritance
Available extensions

Values

provider → const StateManagement
riverpod → const StateManagement
getx → const StateManagement
bloc → const StateManagement

Properties

extraPackages String

Available on StateManagement, provided by the StateManagementExt extension

Returns additional packages required for this state management solution.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String

Available on StateManagement, provided by the StateManagementExt extension

Returns the human-readable label for this state management solution.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
packageName String

Available on StateManagement, provided by the StateManagementExt extension

Returns the pubspec package dependency string for this state management solution.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StateManagement>
A constant List of the values in this enum, in order of their declaration.