Console class

Constructors

Console()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

error(String msg) → void
info(String msg) → void
inputText(String message, {String defaultVal = ''}) String
panelClose() → void
panelOpen(String label) → void
┌─ LABEL ──────────────────────────┐
panelRow(String content) → void
printBanner() → void
printFeatureList(List<String> features) → void
printUsecaseList(String feature, List<String> usecases) → void
progressBar(String label, int percent, {String status = ''}) → void
Renders inline: ██████░░░░ 60% BUILDING
prompt(String message, {String? defaultVal}) String?
selectFromList(String title, List<String> options) int
Arrow-key select — returns chosen index
selectMultipleFromList(String title, List<String> options) List<int>
Checkbox select — returns list of chosen indices
separator() → void
statusPanelClose() → void
statusPanelOpen(String label) → void
╔─ STATUS ────────────╗ (double line variant)
statusPanelRow(String content) → void
step(String msg) → void
success(String msg) → void
typewriter(String text, {int delayMs = 18, String color = _cy}) → void
warning(String msg) → void

Constants

bold → const String
cyan → const String
dim → const String
gray → const String
green → const String
red → const String
reset → const String
yellow → const String