AppGenerator class
Generates the app entry points (main.dart and app.dart).
Creates the main.dart file with appropriate initialization and app.dart with routing configuration based on state management.
Constructors
- AppGenerator(String projectPath, ProjectConfig config)
- Creates a new AppGenerator.
Properties
- config → ProjectConfig
-
The project configuration.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- libPath → String
-
Returns the path to the lib directory.
no setter
- projectPath → String
-
The path to the Flutter project.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generate(
) → void - Generates the main.dart and app.dart files.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited